
## CATO-CLI - mutation.accountManagement.updateAccount:
[Click here](https://api.catonetworks.com/documentation/#mutation-updateAccount) for documentation on this operation.

### Usage for mutation.accountManagement.updateAccount:

`catocli mutation accountManagement updateAccount -h`

`catocli mutation accountManagement updateAccount <json>`

`catocli mutation accountManagement updateAccount "$(cat < updateAccount.json)"`

`catocli mutation accountManagement updateAccount '{"updateAccountInput": {"description": {"description": "String"}}}'`

#### Operation Arguments for mutation.accountManagement.updateAccount ####
`accountId` [ID] - (required) N/A 
`updateAccountInput` [UpdateAccountInput] - (required) N/A 
